
# Installation

You can install the library using `pip` with a virtual environment as follows:
```shell
python -m venv .env
source .env/bin/activate
pip install biome-text
```

After installing biome.text, the best way to test your installation is by running the `biome.text` cli command:
```shell
biome.text --help
```

For development installations, contributing or getting help see the [Community](/community/) section.
